from setuptools import setup

setup(
    name='turboedge',
    version='0.0.1',
    description='',
    long_description='',
    url='https://people.eecs.berkeley.edu/~shishirpatil/',
    author='Shishir Patil',
    author_email='shishirpatil@berkeley.edu',
    packages=[],
    classifiers=['Development Status :: 2 - Pre-Alpha'],
)
